pub struct Globals(/* private fields */);Expand description
A map of environment names to their global variable maps.
Implementations
Sourceimpl Globals
impl Globals
Sourcepub fn entries(
&self,
) -> impl Iterator<Item = (&'static str, &'static Map<&'static str, bool>)> + '_
pub fn entries( &self, ) -> impl Iterator<Item = (&'static str, &'static Map<&'static str, bool>)> + '_
Returns an iterator over the entries of the globals map.
Sourcepub fn get(&self, key: &str) -> Option<&'static Map<&'static str, bool>>
pub fn get(&self, key: &str) -> Option<&'static Map<&'static str, bool>>
Returns the globals map for the given environment name.
Sourcepub fn values(
&self,
) -> impl Iterator<Item = &'static Map<&'static str, bool>> + '_
pub fn values( &self, ) -> impl Iterator<Item = &'static Map<&'static str, bool>> + '_
Returns an iterator over the values of the globals map.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Returns true if the globals map contains the given environment name.